@@ -7,7 +7,8 @@
 struct f { int w; int x[]; };
 struct g { struct f f; };
 struct g g1 = { { 0, { } } };
-struct g g2 = { { 0, { 1 } } }; /* { dg-error "(nested context)|(near initialization)" "nested" } */
-
+struct g g2 = { { 0, { 1 } } }; /* { dg-error "nested context" "nested" } */
+				/* { dg-error "near init" "near" { target *-*-* } 10 } */
 struct h { int x[0]; int y; };
-struct h h1 = { { 0 }, 1 }; /* { dg-error "(excess elements)|(near initialization)" "before end" } */
+struct h h1 = { { 0 }, 1 }; /* { dg-warning "excess elements" "excess" } */
+			    /* { dg-warning "near init" "before end" { target *-*-* } 13 } */
