@@ -3,7 +3,7 @@
 
 /* { dg-do compile } */
 
-#include <objc/Object.h>
+#include "../objc-obj-c++-shared/Object1.h"
 #include <iostream>
 #include <string>
 
